import pytest
from orchestrator.types import SubscriptionLifecycle

from gso.products import ProductName
from gso.products.product_types.office_router import ImportedOfficeRouter
from gso.products.product_types.site import Site
from test.workflows import (
    assert_complete,
    extract_state,
    run_workflow,
)


@pytest.fixture()
def workflow_input_data(faker, site_subscription_factory):
    return {
        "partner": "GEANT",
        "office_router_site": Site.from_subscription(site_subscription_factory()).site.site_name,
        "office_router_fqdn": faker.domain_name(levels=4),
        "office_router_ts_port": faker.port_number(is_user=True),
        "office_router_lo_ipv4_address": faker.ipv4(),
        "office_router_lo_ipv6_address": faker.ipv6(),
    }


@pytest.mark.workflow()
def test_create_imported_office_router_success(workflow_input_data):
    result, _, _ = run_workflow("create_imported_office_router", [workflow_input_data])
    state = extract_state(result)
    imported_office_router = ImportedOfficeRouter.from_subscription(state["subscription_id"])

    assert_complete(result)
    assert imported_office_router.product.name == ProductName.IMPORTED_OFFICE_ROUTER
    assert imported_office_router.status == SubscriptionLifecycle.ACTIVE
